%Supplementary to Sinnesael et al., Anticosti cyclostratigraphy, Vaural
%Formation.

%This script uses functions "DetrendSignalPP",
%"SpectralMoments_with_SR_estimation"  as Published in
%Sinnesael et al., 2018, Paleoceanography and Paleoclimatology and can be found
%for free at: https://agupubs.onlinelibrary.wiley.com/doi/full/10.1029/2017PA003293


%START_Spectral_Moments_MAINSCRIPT
%
% About:
%   This script is part of the supplementary material for the manuscript
%   entitled "Using Spectral Moments in Cyclostratigraphy, Advantages and 
%   Disadvantages Compared to More Classic Approaches", submitted to 
%   Paleoceanography and Paleoclimatology
%   (Sinnesael M., Zivanovic M., De Vleeschouwer D., Claeys P., 2018)
%   (Last update: 14/03/2018).
%
%   This mainscript contains three main parts:
%
%   1) DATA INPUT: load your data, for example as a text file
%
%   2) PARAMETER SPECIFICATION: specify the model parameters
%
%   3) CALCULATIONS & BASIC GRAPHICAL OUTPUT: 
%   run the main function and return numerical/graphical output.
%
%   The user is free to make customize the plotting 
%   statements or to export the variables and plot them elsewhere.  

% HINT: code can be disabled by putting a "%" in front of the line of code 
% (will turn into green color). The black lines in this script are the
% active executing code. 

% start timer, when you see "Elapsed time is X.XX seconds." in the
% Command Window, you know that the whole script ran.
tic 

% clear previous variables and close all open figures
clear all
close all
clc

%______________________________________________________________
%
% 1) --- DATA INPUT ---
%______________________________________________________________
%
% - !!! DEPTH SCALE HAS TO BE UNIFORMLY SAMPLED!!! 
% IF YOUR ORIGINAL DATA IS NOT, WE SUGGEST INTERPOLATION BEFORE USING
% OF THIS ROUTINE

% - In the current code, the data is loaded as a text-file, but the user is
% free to use other formats (and adapt the MATLAB code accordingly).

%   data              Stratigraphic series: first column should be depth 
%                     (meters), second column should be data value.
%                     !!!Uniform sampling is assumed.!!! 

data = load('L20_403_880.txt');

%______________________________________________________________
%
% 2) --- PARAMETER SPECIFICATION ---
%______________________________________________________________
%
% Specification of the model parameters which will be used in the
% functions.
%
% Input:
%
%   data              Stratigraphic series: first column should be depth 
%                     (in meters), second column should be data value.
%                     Uniform sampling is assumed.
%
%   windowsize        length of the analysis frame in meters                     
%
%   fs                Sampling rate in the depth domain 
%                     [!!! as number of samples per meter !!!]
%
% Example:
%       SpectralMoments_no_SR_estimation(data,20,10)
%       
% *Optional Use* for (sedimentation rate) trend estimation
%
%   T0                Time period [kyr] of an (orbital) component to 
%                     calculate the sedimentation rate trend.
%
%   F0                Spatial frequency [cycle/m] of the (orbital) component
%                     at the begining of the data record.
%
% Example:
%       SpectralMoments_with_SR_estimation(data,20,10,41,0.97)

data = data; %Step one, data input

windowsize = 25; % e.g. = 20; length of the analysis frame in meters

fs = 10; % e.g. = 10; number of samples per meter

% *Optional Use* for sedimentation rate trend estimation
% HINT: code can be disabled by putting a "%" in front of the line of code 
% (will turn into green color). The black lines in this script is the
% active executing code. 

T0 = 18.725; %e.g. 41 ; Time period [kyr] of an (orbital) component

F0 = 0.13;%e.g. 0.97 ; Spatial frequency [cycle/m] of the (orbital) component 

%______________________________________________________________
%
% 3) --- CALCULATIONS & BASIC GRAPHICAL OUTPUT ---
%______________________________________________________________
%
% !!! DEPENDING ON THE ESTIMATION OF THE (SEDIMENTATION RATE) TREND OF THE 
% SPECTRAL MOMENTS, THE USER CAN CHOSE 3I or 3II.[(UN)COMMENT] !!!
% 
% !!! In both functions for the estimation of the spectral moments, there
% is the option to apply for polynomial detrending(using a moving 
% framesize) of the signal. The user can chose to do this or not by 
% (un)commenting the "DetrendSignalPP.m" inside the actual functions. 
% By default, it the detrending is not activated. !!!
%
% HINT: code can be disabled by putting a "%" in front of the line of code 
% (will turn into green color). The black lines in this script is the
% active executing code. 

% 3I) Spectral Moments without optional sedimentation rate trend estimation
%______________________________________________________________

%CALCULATION
% function SpectralMoments_no_SR_estimation(data,windowsize,fs)
SpectralMoments_no_SR_estimation(data,windowsize,fs)

%RETURN NUMERICAL OUTPUT
load('SpectralMoments.mat')

%
% 3II) Spectral Moments with optional sedimentation rate trend estimation
%______________________________________________________________

%CALCULATION
%function SpectralMoments_with_SR_estimation(data,windowsize,fs,T0,F0)
SpectralMoments_with_SR_estimation(data,windowsize,fs,T0,F0)

%RETURN NUMERICAL OUTPUT
%load('SpectralMoments.mat')


%end timer
toc 

%END Spectral_Moments_MAINSCRIPT